Documentation
¶
Overview ¶
Package booking API.
the purpose of this application is to provide an application that is using plain go code to define an API
Schemes: https Host: localhost Version: 0.0.1 Consumes: - application/json Produces: - application/json
swagger:meta
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BookingResponse ¶
type BookingResponse struct {
// Booking struct
//
// in: body
// required: true
Booking makeplans.Booking `json:"booking"`
}
BookingResponse represents a scheduled appointment
swagger:response BookingResponse
Click to show internal directories.
Click to hide internal directories.